@@ -1,5 +1,6 @@
 use std::env::consts::EXE_EXTENSION;
 use std::fs;
+use tempfile::TempDir;
 
 use crate::common::{rye_cmd_snapshot, Space};
 
@@ -9,6 +10,9 @@ mod common;
 fn test_basic_tool_behavior() {
     let space = Space::new();
 
+    // Cache alongside the home directory, so that the cache lives alongside the tools directory.
+    let cache_dir = TempDir::new_in(space.rye_home()).unwrap();
+
     // in case we left things behind from last run.
     fs::remove_dir_all(space.rye_home().join("tools")).ok();
     fs::remove_file(
@@ -22,6 +26,7 @@ fn test_basic_tool_behavior() {
 
     rye_cmd_snapshot!(
         space.rye_cmd()
+            .env("UV_CACHE_DIR", cache_dir.path())
             .arg("tools")
             .arg("install")
             .arg("pycowsay")
@@ -43,6 +48,7 @@ fn test_basic_tool_behavior() {
 
     rye_cmd_snapshot!(
         space.rye_cmd()
+            .env("UV_CACHE_DIR", cache_dir.path())
             .arg("tools")
             .arg("list"), @r###"
     success: true
@@ -55,6 +61,7 @@ fn test_basic_tool_behavior() {
 
     rye_cmd_snapshot!(
         space.rye_cmd()
+            .env("UV_CACHE_DIR", cache_dir.path())
             .arg("tools")
             .arg("list")
             .arg("--include-version"), @r###"
@@ -68,6 +75,7 @@ fn test_basic_tool_behavior() {
 
     rye_cmd_snapshot!(
         space.rye_cmd()
+            .env("UV_CACHE_DIR", cache_dir.path())
             .arg("toolchain")
             .arg("remove")
             .arg("cpython@3.11.9"), @r###"
@@ -81,6 +89,7 @@ fn test_basic_tool_behavior() {
 
     rye_cmd_snapshot!(
         space.rye_cmd()
+            .env("UV_CACHE_DIR", cache_dir.path())
             .arg("tools")
             .arg("uninstall")
             .arg("pycowsay"), @r###"
